@@ -10,8 +10,14 @@ cnapath <- function(cna, from, to=NULL, k=10, collapse=TRUE, ncore=NULL, ...) {
   if (!oops) 
      stop("igraph package missing: Please install, see: ?install.packages")
   
-  if(!inherits(cna, "cna")) 
+  if(!inherits(cna, "cna")) {
+     if(is.list(cna)) {
+        paths <- lapply(cna, cnapath, from=from, to=to, k=k, collapse=collapse, ncore=ncore, ...)
+        class(paths) <- c("ecnapath", class(paths))
+        return( paths )
+     } 
      stop("Input cna is not a 'cna' object")
+  }
 
   ncore = setup.ncore(ncore)
 
@@ -40,13 +46,26 @@ cnapath <- function(cna, from, to=NULL, k=10, collapse=TRUE, ncore=NULL, ...) {
   paths <- mclapply(pairs, function(x)
               .cnapath.core(cna=cna, from=x$from, to=x$to, k=k, ncore=ncore.in, 
                  pb=pb, ...), mc.cores=ncore.out)
+  
+  rm.inds <- sapply(paths, is.null)
+  if(sum(rm.inds) == length(paths)) {
+     warning(paste("  No path found.\n", 
+         "  Please check if the network contains isolated parts!\n\n", sep=""))
+     paths <- NULL
+  } else {
 
-  if(collapse) {
-     cls <- class(paths[[1]])
-     coms <- names(paths[[1]])
-     paths <- lapply(coms, function(x) do.call(c, lapply(paths, "[[", x)) )
-     names(paths) <- coms 
-     class(paths) <- cls
+      if(collapse) {
+         paths <- paths[!rm.inds]
+         cls <- class(paths[[1]])
+         coms <- names(paths[[1]])
+         paths <- lapply(coms, function(x) do.call(c, lapply(paths, "[[", x)) )
+         names(paths) <- coms 
+         class(paths) <- cls
+      }
+      if(sum(rm.inds)>0) {
+         warning(paste("  No path found for some source/sink pairs.\n", 
+         "  Please check if the network contains isolated parts!\n\n", sep=""))
+      }
   }
 
   ## Finish progress bar
@@ -70,12 +89,13 @@ cnapath <- function(cna, from, to=NULL, k=10, collapse=TRUE, ncore=NULL, ...) {
   }
 
   # first shortest path
-  k0 <- igraph::get.shortest.paths(graph, from, to, output='both', ...)
+  k0 <- suppressWarnings( igraph::get.shortest.paths(graph, from, to, output='both', ...) )
   
   # if no shortest path found, network contains isolated parts.
   if(length(k0$vpath[[1]]) <= 1) {
-     cat("  No path found.\n", 
-         "  Please check if the network contains isolated parts!\n\n", sep="")
+#     cat("  No path found.\n", 
+#         "  Please check if the network contains isolated parts!\n\n", sep="")
+     if(!is.null(pb)) .update.pb(pb, step=k)
      return(NULL)
   }
 
@@ -114,7 +134,7 @@ cnapath <- function(cna, from, to=NULL, k=10, collapse=TRUE, ncore=NULL, ...) {
        # Remove all edges that link to nodes on the root path (excluding the spur node)
        if(i > 1) {
           for(j in rootPath[-(length(rootPath))]) {
-             ee = igraph::E(g)[from(j)] 
+             ee = igraph::incident(g, j) 
              if(length(ee)>0) g <- igraph::delete.edges(g, ee)
           }
        }
